@@ -11,8 +11,8 @@ def register_fausans_font():
 
     After successful registration, the font can be used in matplotlib by setting the following rcParams:
     >>> import matplotlib.pyplot as plt
-    >>> plt.rcParams['font.family'] = 'sans-serif'
-    >>> plt.rcParams['font.sans-serif'] = 'FAUSans Office'
+    >>> plt.rcParams["font.family"] = "sans-serif"
+    >>> plt.rcParams["font.sans-serif"] = "FAUSans Office"
 
 
     Raises
@@ -29,7 +29,12 @@ def register_fausans_font():
     for path in possible_paths:
         if path.exists():
             font_manager.fontManager.addfont(path)
-            print("Successfully registered FAU Sans font.")
+            print(
+                "Successfully registered FAU Sans font. "
+                "You can now use it in matplotlib by adding the following lines to your code:\n\n"
+                'plt.rcParams["font.family"] = "sans-serif"'
+                'plt.rcParams["font.sans-serif"] = "FAUSans Office"'
+            )
             return
 
     raise FileNotFoundError(
